@@ -9,6 +9,9 @@ class PdpRepo:
 
     __DYNAMODB_RESOURCE = boto3.resource("dynamodb")
 
+    __DEFAULT_ENTITY_URI_FIELD_NAME = "entityUri"
+    __DEFAULT_POLICY_TYPE_FIELD_NAME = "policyType"
+
     def __init__(self, 
             policiesTableName:str, 
             policiesTableEntityUriFieldName:str = "entityUri",
@@ -25,6 +28,10 @@ class PdpRepo:
         policyDict = ObjectUtil.toDict(policy)
         policyDict[self.__policiesTableEntityUriFieldName] = self.__prefixKeyFieldValue(policy.entityUri)
         policyDict[self.__policiesTablePolicyTypeFieldName] = self.__prefixKeyFieldValue(policy.policyType)
+        if self.__policiesTableEntityUriFieldName != PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME:
+            del policyDict[PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME]
+        if self.__policiesTablePolicyTypeFieldName != PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME:
+            del policyDict[PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME]
         self.__policiesDdbTableResource.put_item(
             Item = policyDict
         )
@@ -109,7 +116,11 @@ class PdpRepo:
 
     def __policyDictToPolicy(self, policyDict:Dict) -> Policy:
         return ObjectUtil.fromDict(
-            dictValue = policyDict,
+            dictValue = {
+                **policyDict,
+                PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTableEntityUriFieldName]),
+                PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTablePolicyTypeFieldName]),
+            },
             objectType = Policy
         )
 
